@@ -31,9 +31,11 @@
 #ifdef AESNI_EMU
 #include "include/noaesni.h"
 #endif
-#include "asm.h"
 #include "include/clear_regs_mem.h"
 #include "include/error.h"
+#include "include/arch_noaesni.h"
+#include "include/arch_sse_type1.h"
+#include "include/arch_avx_type1.h"
 
 static uint32_t in[4*3] = {
         0x01010101, 0x01010101, 0x01010101, 0x01010101,
