@@ -84,6 +84,11 @@ const struct {
 	OOO_INFO(aes256_cmac_ooo, MB_MGR_CMAC_OOO),
         OOO_INFO(snow3g_uea2_ooo, MB_MGR_SNOW3G_OOO),
         OOO_INFO(snow3g_uia2_ooo, MB_MGR_SNOW3G_OOO),
+        OOO_INFO(sha_1_ooo, MB_MGR_SHA_1_OOO),
+        OOO_INFO(sha_224_ooo, MB_MGR_SHA_256_OOO),
+        OOO_INFO(sha_256_ooo, MB_MGR_SHA_256_OOO),
+        OOO_INFO(sha_384_ooo, MB_MGR_SHA_512_OOO),
+        OOO_INFO(sha_512_ooo, MB_MGR_SHA_512_OOO)
 };
 
 /**
@@ -160,6 +165,7 @@ static void set_ooo_mgr_road_block(IMB_MGR *mgr)
  *     IMB_FLAG_SHANI_OFF - disable use (and detection) of SHA extensions,
  *                          currently SHANI is only available for SSE
  *     IMB_FLAG_AESNI_OFF - disable use (and detection) of AES extensions.
+ *     IMB_FLAG_GFNI_OFF - disable use (and detection) of Galois Field extensions.
  *
  * @param reset_mgr if 0, IMB_MGR structure is not cleared, else it is.
  *
@@ -175,7 +181,7 @@ IMB_MGR *imb_set_pointers_mb_mgr(void *mem_ptr, const uint64_t flags,
 
         IMB_MGR *ptr = (IMB_MGR *) mem_ptr;
         uint8_t *ptr8 = (uint8_t *) ptr;
-        uint8_t *free_mem = &ptr8[ALIGN(sizeof(IMB_MGR), ALIGNMENT)];
+        uint8_t *free_ptr = &ptr8[ALIGN(sizeof(IMB_MGR), ALIGNMENT)];
         const size_t mem_size = imb_get_mb_mgr_size();
         unsigned i;
 
@@ -226,9 +232,9 @@ IMB_MGR *imb_set_pointers_mb_mgr(void *mem_ptr, const uint64_t flags,
 
         /* Set OOO pointers */
         for (i = 0; i < IMB_DIM(ooo_mgr_table); i++) {
-                set_ooo_ptr(ptr, ooo_mgr_table[i].ooo_ptr_offset, free_mem);
-                free_mem = &free_mem[ooo_mgr_table[i].ooo_aligned_size];
-                IMB_ASSERT((uintptr_t)(free_mem - ptr8) <= mem_size);
+                set_ooo_ptr(ptr, ooo_mgr_table[i].ooo_ptr_offset, free_ptr);
+                free_ptr = &free_ptr[ooo_mgr_table[i].ooo_aligned_size];
+                IMB_ASSERT((uintptr_t)(free_ptr - ptr8) <= mem_size);
         }
         set_ooo_mgr_road_block(ptr);
 
@@ -272,6 +278,7 @@ free_mem(void *ptr)
  *     IMB_FLAG_SHANI_OFF - disable use (and detection) of SHA extensions,
  *                          currently SHANI is only available for SSE
  *     IMB_FLAG_AESNI_OFF - disable use (and detection) of AES extensions.
+ *     IMB_FLAG_GFNI_OFF - disable use (and detection) of Galois Field extensions.
  *
  * @return Pointer to allocated memory for MB_MGR structure
  * @retval NULL on allocation error
