@@ -83,7 +83,16 @@ IMB_DLL_LOCAL const int imb_errno_types[] = {
         IMB_ERR_JOB_NULL_HMAC_IPAD,
         IMB_ERR_JOB_NULL_XCBC_K1_EXP,
         IMB_ERR_JOB_NULL_XCBC_K2,
-        IMB_ERR_JOB_NULL_XCBC_K3
+        IMB_ERR_JOB_NULL_XCBC_K3,
+        IMB_ERR_JOB_CIPH_DIR,
+        IMB_ERR_JOB_NULL_GHASH_INIT_TAG,
+        IMB_ERR_MISSING_CPUFLAGS_INIT_MGR,
+        IMB_ERR_NULL_JOB,
+        IMB_ERR_QUEUE_SPACE,
+        IMB_ERR_NULL_BURST,
+        IMB_ERR_BURST_SIZE,
+        IMB_ERR_BURST_OOO,
+        IMB_ERR_SELFTEST
 };
 
 #ifdef DEBUG
@@ -162,6 +171,8 @@ imb_get_strerror(int errnum)
                 return "Null pointer to XCBC K2";
         case IMB_ERR_JOB_NULL_XCBC_K3:
                 return "Null pointer to XCBC K3";
+        case IMB_ERR_JOB_NULL_GHASH_INIT_TAG:
+                return "Null pointer to GHASH initial tag value";
         case IMB_ERR_NULL_SRC:
                 return "Null source pointer (direct API)";
         case IMB_ERR_NULL_DST:
@@ -198,6 +209,23 @@ imb_get_strerror(int errnum)
                 return "Null pointer to context (direct API)";
         case IMB_ERR_NO_AESNI_EMU:
                 return "No AESNI emulation support";
+        case IMB_ERR_JOB_CIPH_DIR:
+                return "Invalid cipher direction";
+        case IMB_ERR_MISSING_CPUFLAGS_INIT_MGR:
+                return "Failed to initialize IMB_MGR due to missing "
+                       "required CPU flags";
+        case IMB_ERR_NULL_JOB:
+                return "NULL job pointer";
+        case IMB_ERR_QUEUE_SPACE:
+                return "Not enough space in job queue";
+        case IMB_ERR_NULL_BURST:
+                return "NULL pointer to burst job array";
+        case IMB_ERR_BURST_SIZE:
+                return "Invalid burst size";
+        case IMB_ERR_BURST_OOO:
+                return "Burst jobs out of order";
+        case IMB_ERR_SELFTEST:
+                return "Self-test failed";
         default:
                 return strerror(errnum);
         }
