@@ -1,5 +1,5 @@
 /*****************************************************************************
- Copyright (c) 2017-2021, Intel Corporation
+ Copyright (c) 2017-2022, Intel Corporation
 
  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions are met:
@@ -36,7 +36,7 @@
 #include "gcm_ctr_vectors_test.h"
 #include "utils.h"
 
-int des_test(const enum arch_type arch, struct IMB_MGR *mb_mgr);
+int des_test(struct IMB_MGR *mb_mgr);
 
 struct des_vector {
 	const uint8_t *K;          /* key */
@@ -610,14 +610,11 @@ test_des3_vectors(struct IMB_MGR *mb_mgr,
 }
 
 int
-des_test(const enum arch_type arch,
-         struct IMB_MGR *mb_mgr)
+des_test(struct IMB_MGR *mb_mgr)
 {
         struct test_suite_context ctx;
         int errors;
 
-        (void) arch;
-
         test_suite_start(&ctx, "DES-CBC-64");
         test_des_vectors(mb_mgr, DIM(vectors), vectors,
                          "DES standard test vectors", IMB_CIPHER_DES, &ctx);
